=begin comment

Web API Swagger specification

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

OpenAPI spec version: 1.0

Generated by: https://github.com/swagger-api/swagger-codegen.git

=end comment

=cut

#
# NOTE: This class is auto generated by Swagger Codegen
# Please update the test cases below to test the API endpoints.
# Ref: https://github.com/swagger-api/swagger-codegen
#
use Test::More tests => 1; #TODO update number of test cases
use Test::Exception;

use lib 'lib';
use strict;
use warnings;
require 't\CellsTestBase.pl';
my $new_client = get_client();
my $result = undef;
my $BOOK1 = 'Book1.xlsx';
my $MYDOC = 'myDocument.xlsx';
my $PVTESTFILE = 'TestCase.xlsx';
my $TEMPFOLDER = 'Temp';
my $SHEET1 = 'Sheet1';
my $SHEET2 = 'Sheet2';
my $SHEET3 = 'Sheet3';
my $SHEET4 = 'Sheet4';
my $SHEET5 = 'Sheet5';
my $SHEET6 = 'Sheet6';
my $SHEET7 = 'Sheet7';
my $SHEET8 = 'Sheet8';
my $CELLNAME = 'A1';
my $RANGE = 'A1:C10';
my $CELLAREA = 'A1:C10';
use_ok('AsposeCellsCloud::CellsSaveAsApi');

my $api = AsposeCellsCloud::CellsSaveAsApi->new($new_client);
isa_ok($api, 'AsposeCellsCloud::CellsSaveAsApi');

#
# cells_save_as_post_document_save_as test
#
{
    my $name = $BOOK1; # replace NULL with a proper value
    my $save_options = undef; # replace NULL with a proper value
    my $newfilename = 'newbook.xlsx'; # replace NULL with a proper value
    my $is_auto_fit_rows = 'true'; # replace NULL with a proper value
    my $is_auto_fit_columns = 'true'; # replace NULL with a proper value
    my $folder = $TEMPFOLDER ; # replace NULL with a proper value
    $result = $api->cells_save_as_post_document_save_as(name => $name,
     save_options => $save_options, 
     newfilename => $newfilename, 
     is_auto_fit_rows => $is_auto_fit_rows, 
     is_auto_fit_columns => $is_auto_fit_columns, 
     folder => $folder);
    ok($result->status eq 'OK' ,'cells_save_as_post_document_save_as OK');
}


1;
