=begin comment

Web API Swagger specification

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

OpenAPI spec version: 1.0

Generated by: https://github.com/swagger-api/swagger-codegen.git

=end comment

=cut

#
# NOTE: This class is auto generated by Swagger Codegen
# Please update the test cases below to test the API endpoints.
# Ref: https://github.com/swagger-api/swagger-codegen
#
use Test::More tests => 1; #TODO update number of test cases
use Test::Exception;

use lib 'lib';
use strict;
use warnings;

use_ok('AsposeCellsCloud::OAuthApi');
use_ok('AsposeCellsCloud::Configuration');
use_ok('AsposeCellsCloud::ApiClient');
use_ok('AsposeCellsCloud::CellsChartsApi');
use_ok('AsposeCellsCloud::Object::ColumnsResponse');
use_ok('AsposeCellsCloud::Object::Chart');
use_ok('AsposeCellsCloud::Object::Legend');
use_ok('AsposeCellsCloud::Object::Title');
use_ok('AsposeCellsCloud::Object::FontSetting');
use_ok('AsposeCellsCloud::Object::Style');
use_ok('AsposeCellsCloud::Object::SaaSposeResponse');
require 't\CellsTestBase.pl';
my $new_client = get_client();
my $result =undef;
copy_to_temp_2();
my $BOOK1 = 'Book1.xlsx';
my $MYDOC = 'myDocument.xlsx';
my $PVTESTFILE = 'TestCase.xlsx';
my $TEMPFOLDER = 'Temp';
my $SHEET1 = 'Sheet1';
my $SHEET2 = 'Sheet2';
my $SHEET3 = 'Sheet3';
my $SHEET4 = 'Sheet4';
my $SHEET5 = 'Sheet5';
my $SHEET6 = 'Sheet6';
my $SHEET7 = 'Sheet7';
my $SHEET8 = 'Sheet8';
my $CELLNAME = 'A1';
my $RANGE = 'A1:C10';
my $CELLAREA = 'A1:C10';


my $api = AsposeCellsCloud::CellsChartsApi->new( $new_client);
isa_ok($api, 'AsposeCellsCloud::CellsChartsApi');



#
# cells_charts_get_worksheet_chart test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_number = 0; # replace NULL with a proper value
    my $format = 'png'; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_get_worksheet_chart(name => $name, sheet_name => $sheet_name, chart_number => $chart_number, format => $format, folder => $folder);
}

#
# cells_charts_get_worksheet_chart_legend test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 0; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_get_worksheet_chart_legend(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_get_worksheet_chart_legend OK');
}

#
# cells_charts_get_worksheet_chart_title test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 0; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_get_worksheet_chart_title(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_get_worksheet_chart_title OK');
}

#
# cells_charts_get_worksheet_charts test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_get_worksheet_charts(name => $name, sheet_name => $sheet_name, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_get_worksheet_charts OK');
}

#
# cells_charts_post_worksheet_chart test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 0; # replace NULL with a proper value
    my $chart =  AsposeCellsCloud::Object::Chart->new(auto_scaling => 'true'); # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_post_worksheet_chart(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, chart => $chart, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_post_worksheet_chart OK');
}

#
# cells_charts_post_worksheet_chart_legend test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 0; # replace NULL with a proper value
    my $legend =  AsposeCellsCloud::Object::Legend->new(width => 10); # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_post_worksheet_chart_legend(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, legend => $legend, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_post_worksheet_chart_legend OK');
}

#
# cells_charts_post_worksheet_chart_title test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 0; # replace NULL with a proper value
    my $title =  AsposeCellsCloud::Object::Title->new(text => '10title'); # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_post_worksheet_chart_title(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, title => $title, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_post_worksheet_chart_title OK');
}

#
# cells_charts_put_worksheet_add_chart test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_type = 'pie'; # replace NULL with a proper value
    my $upper_left_row = 5; # replace NULL with a proper value
    my $upper_left_column = 5; # replace NULL with a proper value
    my $lower_right_row = 10; # replace NULL with a proper value
    my $lower_right_column = 10; # replace NULL with a proper value
    my $area = 'C7:D11'; # replace NULL with a proper value
    my $is_vertical = 'true'; # replace NULL with a proper value
    my $category_data = undef; # replace NULL with a proper value
    my $is_auto_get_serial_name = undef; # replace NULL with a proper value
    my $title = undef; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_put_worksheet_add_chart(name => $name, sheet_name => $sheet_name, chart_type => $chart_type, upper_left_row => $upper_left_row, upper_left_column => $upper_left_column, lower_right_row => $lower_right_row, lower_right_column => $lower_right_column, area => $area, is_vertical => $is_vertical, category_data => $category_data, is_auto_get_serial_name => $is_auto_get_serial_name, title => $title, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_put_worksheet_add_chart OK');
}

#
# cells_charts_put_worksheet_chart_legend test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 0; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_put_worksheet_chart_legend(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_put_worksheet_chart_legend OK');
}

#
# cells_charts_put_worksheet_chart_title test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 0; # replace NULL with a proper value
    my $title =  AsposeCellsCloud::Object::Title->new(text => '11title'); # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_put_worksheet_chart_title(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, title => $title, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_put_worksheet_chart_title OK');
}

#
# cells_charts_delete_worksheet_chart_legend test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 1; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_delete_worksheet_chart_legend(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, folder => $folder);
}

#
# cells_charts_delete_worksheet_chart_title test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 1; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_delete_worksheet_chart_title(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_delete_worksheet_chart_title OK');
}

#
# cells_charts_delete_worksheet_delete_chart test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $chart_index = 0; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_delete_worksheet_delete_chart(name => $name, sheet_name => $sheet_name, chart_index => $chart_index, folder => $folder);
    ok($result->status eq 'OK' ,'cells_charts_delete_worksheet_delete_chart OK');
}

#
# cells_charts_delete_worksheet_clear_charts test
#
{
    my $name = $MYDOC; # replace NULL with a proper value
    my $sheet_name = $SHEET3; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_charts_delete_worksheet_clear_charts(name => $name, sheet_name => $sheet_name, folder => $folder);
}
1;
