=begin comment

Web API Swagger specification

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

OpenAPI spec version: 1.0

Generated by: https://github.com/swagger-api/swagger-codegen.git

=end comment

=cut

#
# NOTE: This class is auto generated by Swagger Codegen
# Please update the test cases below to test the API endpoints.
# Ref: https://github.com/swagger-api/swagger-codegen
#
use Test::More tests => 1; #TODO update number of test cases
use Test::Exception;

use lib 'lib';
use strict;
use warnings;

use_ok('AsposeCellsCloud::OAuthApi');
use_ok('AsposeCellsCloud::Configuration');
use_ok('AsposeCellsCloud::ApiClient');
use_ok('AsposeCellsCloud::CellsOleObjectsApi');
use_ok('AsposeCellsCloud::Object::ColumnsResponse');
use_ok('AsposeCellsCloud::Object::OleObject');
use_ok('AsposeCellsCloud::Object::FontSetting');
use_ok('AsposeCellsCloud::Object::Style');
use_ok('AsposeCellsCloud::Object::SaaSposeResponse');

require 't\CellsTestBase.pl';
my $new_client = get_client();
my $result =undef;
copy_to_temp_1();

my $BOOK1 = 'Book1.xlsx';
my $MYDOC = 'myDocument.xlsx';
my $PVTESTFILE = 'TestCase.xlsx';
my $TEMPFOLDER = 'Temp';
my $SHEET1 = 'Sheet1';
my $SHEET2 = 'Sheet2';
my $SHEET3 = 'Sheet3';
my $SHEET4 = 'Sheet4';
my $SHEET5 = 'Sheet5';
my $SHEET6 = 'Sheet6';
my $SHEET7 = 'Sheet7';
my $SHEET8 = 'Sheet8';
my $CELLNAME = 'A1';
my $RANGE = 'A1:C10';
my $CELLAREA = 'A1:C10';




use_ok('AsposeCellsCloud::CellsOleObjectsApi');

my $api = AsposeCellsCloud::CellsOleObjectsApi->new($new_client);
isa_ok($api, 'AsposeCellsCloud::CellsOleObjectsApi');




#
# cells_ole_objects_put_worksheet_ole_object test
#
{
    my $name = $BOOK1; # replace NULL with a proper value
    my $sheet_name = $SHEET6; # replace NULL with a proper value
    my $ole_object = undef; # replace NULL with a proper value
    my $upper_left_row = 1; # replace NULL with a proper value
    my $upper_left_column = 1; # replace NULL with a proper value
    my $height = 100; # replace NULL with a proper value
    my $width = 80; # replace NULL with a proper value
    my $ole_file = 'OLEDoc.docx'; # replace NULL with a proper value
    my $image_file = 'word.jpg'; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_ole_objects_put_worksheet_ole_object(name => $name, sheet_name => $sheet_name, ole_object => $ole_object, upper_left_row => $upper_left_row, upper_left_column => $upper_left_column, height => $height, width => $width, ole_file => $ole_file, image_file => $image_file, folder => $folder);
    ok($result->status eq 'OK' ,'cells_ole_objects_put_worksheet_ole_object OK');
}
#
# cells_ole_objects_get_worksheet_ole_object test
#
{
    my $name = $BOOK1; # replace NULL with a proper value
    my $sheet_name = $SHEET6; # replace NULL with a proper value
    my $object_number = 0; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_ole_objects_get_worksheet_ole_object(name => $name, sheet_name => $sheet_name, object_number => $object_number, folder => $folder);
}

#
# cells_ole_objects_get_worksheet_ole_objects test
#
{
    my $name = $BOOK1; # replace NULL with a proper value
    my $sheet_name = $SHEET6; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_ole_objects_get_worksheet_ole_objects(name => $name, sheet_name => $sheet_name, folder => $folder);
    ok($result->status eq 'OK' ,'cells_ole_objects_get_worksheet_ole_objects OK');
}

#
# cells_ole_objects_post_update_worksheet_ole_object test
#
{
    my $name = $BOOK1; # replace NULL with a proper value
    my $sheet_name = $SHEET6; # replace NULL with a proper value
    my $ole_object_index = 0; # replace NULL with a proper value
    my $ole = AsposeCellsCloud::Object::OleObject->new(width => 100); # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_ole_objects_post_update_worksheet_ole_object(name => $name, sheet_name => $sheet_name, ole_object_index => $ole_object_index, ole => $ole, folder => $folder);
    ok($result->status eq 'OK' ,'cells_ole_objects_post_update_worksheet_ole_object OK');
}

#
# cells_ole_objects_delete_worksheet_ole_object test
#
{
    my $name = $BOOK1; # replace NULL with a proper value
    my $sheet_name = $SHEET6; # replace NULL with a proper value
    my $ole_object_index = 0; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_ole_objects_delete_worksheet_ole_object(name => $name, sheet_name => $sheet_name, ole_object_index => $ole_object_index, folder => $folder);
    ok($result->status eq 'OK' ,'cells_ole_objects_delete_worksheet_ole_object OK');
}

#
# cells_ole_objects_delete_worksheet_ole_objects test
#
{
    my $name = $BOOK1; # replace NULL with a proper value
    my $sheet_name = $SHEET6; # replace NULL with a proper value
    my $folder = $TEMPFOLDER; # replace NULL with a proper value
    $result = $api->cells_ole_objects_delete_worksheet_ole_objects(name => $name, sheet_name => $sheet_name, folder => $folder);
    ok($result->status eq 'OK' ,'cells_ole_objects_delete_worksheet_ole_objects OK');
}
1;
